@@ -66,6 +66,30 @@ def help():
     default=19530,
     type=int,
 )
+@click.option(
+    "-s",
+    "--secure",
+    "secure",
+    help="[Optional] - Secure, default is `False`.",
+    default=False,
+    type=bool,
+)
+@click.option(
+    "-u",
+    "--username",
+    "username",
+    help="[Optional] - Username , default is `None`.",
+    default=None,
+    type=str,
+)
+@click.option(
+    "-pwd",
+    "--password",
+    "password",
+    help="[Optional] - Password , default is `None`.",
+    default=None,
+    type=str,
+)
 @click.option(
     "-D",
     "--disconnect",
@@ -75,7 +99,7 @@ def help():
     is_flag=True,
 )
 @click.pass_obj
-def connect(obj, alias, host, port, disconnect):
+def connect(obj, alias, host, port,secure,username,password, disconnect):
     """
     Connect to Milvus.
 
@@ -84,7 +108,7 @@ def connect(obj, alias, host, port, disconnect):
         milvus_cli > connect -h 127.0.0.1 -p 19530 -a default
     """
     try:
-        obj.connect(alias, host, port, disconnect)
+        obj.connect(alias, host, port, disconnect,secure,username,password)
     except Exception as e:
         click.echo(message=e, err=True)
     else:
@@ -215,6 +239,48 @@ def querySegmentInfo(obj, collection, timeout):
     click.echo(obj.getQuerySegmentInfo(collection, timeout, prettierFormat=True))
 
 
+@show.command("compaction_state")
+@click.option(
+    "-c",
+    "--collection-name",
+    "collection",
+    help="Collection name.",
+)
+@click.option(
+    "-t",
+    "--timeout",
+    "timeout",
+    help="[Optional] - An optional duration of time in seconds to allow for the RPC. When timeout is not set, client waits until server response or error occur.",
+    default=None,
+    type=float,
+)
+@click.pass_obj
+def compactionStateInfo(obj, collection, timeout):
+    """Return the current collection's compaction state."""
+    click.echo(obj.getCompactCollectionState(collection, timeout))
+
+
+@show.command("compaction_plans")
+@click.option(
+    "-c",
+    "--collection-name",
+    "collection",
+    help="Collection name.",
+)
+@click.option(
+    "-t",
+    "--timeout",
+    "timeout",
+    help="[Optional] - An optional duration of time in seconds to allow for the RPC. When timeout is not set, client waits until server response or error occur.",
+    default=None,
+    type=float,
+)
+@click.pass_obj
+def compactionStateInfo(obj, collection, timeout):
+    """Return the current collection's compaction state."""
+    click.echo(obj.getCompactCollectionPlans(collection, timeout))
+
+
 @cli.command()
 @click.option(
     "-c", "--collection-name", "collection", help="The name of collection to load."
@@ -382,6 +448,16 @@ def indexes(obj, collection):
     except Exception as e:
         click.echo(message=e, err=True)
 
+@listDetails.command()
+@click.pass_obj
+def users(obj):
+    """List all users in Milvus"""
+    try:
+        obj.checkConnection()
+        click.echo(obj.listCredUsers())
+    except Exception as e:
+        click.echo(message=e, err=True)
+
 
 @cli.group("describe", no_args_is_help=False)
 @click.pass_obj
@@ -674,6 +750,27 @@ def createIndex(obj):
         click.echo("Create index successfully!")
 
 
+@createDetails.command("user")
+@click.option("-u", "--username", "username", help="The username of milvus user.")
+@click.option("-p", "--password", "password", help="The pawssord of milvus user.")
+@click.pass_obj
+def createUser(obj, username, password):
+    """
+    Create user.
+
+    Example:
+
+        milvus_cli > create user -u zilliz -p zilliz
+    """
+    try:
+        obj.checkConnection()
+        click.echo(obj.createCredUser(username,password))
+        click.echo("Create user successfully")
+    except Exception as e:
+        click.echo(message=e, err=True)
+    
+
+
 @cli.group("delete", no_args_is_help=False)
 @click.pass_obj
 def deleteObject(obj):
@@ -826,6 +923,31 @@ def deleteIndex(obj, collectionName, timeout):
         )
 
 
+@deleteObject.command("user")
+@click.option("-u", "--username", "username", help="The username of milvus user")
+@click.pass_obj
+def deleteUser(obj, username):
+    """
+    Drop user in milvus by username
+
+    Example:
+
+        milvus_cli > delete user -u zilliz
+    """
+    click.echo(
+        "Warning!\nYou are trying to delete the user in milvus. This action cannot be undone!\n"
+    )
+    if not click.confirm("Do you want to continue?"):
+        return
+    try:
+        obj.checkConnection()
+        result = obj.deleteCredUser(username)
+        click.echo("Drop user successfully!")
+        click.echo(result)
+    except Exception as e:
+        click.echo(message=e, err=True)
+   
+
 @deleteObject.command("entities")
 @click.option("-c", "--collection-name", "collectionName", help="Collection name.")
 @click.option(
@@ -1508,6 +1630,22 @@ def loadBalance(obj, src_node_id, dst_node_ids, sealed_segment_ids, timeout):
     click.echo(res)
 
 
+@cli.command("compact")
+@click.option("-c", "--collection-name", "collectionName", help="Collection name")
+@click.option(
+    "-t",
+    "--timeout",
+    "timeout",
+    help="[Optional] - An optional duration of time in seconds to allow for the RPC. If timeout is not set, the client keeps waiting until the server responds or an error occurs.",
+    default=None,
+    type=float,
+)
+@click.pass_obj
+def compactCollection(obj, collectionName, timeout):
+    """Compact merge the small segments in a collection."""
+    obj.compactCollection(collectionName, timeout)
+
+
 @cli.command("exit")
 def quitapp():
     """Exit the CLI."""
