@@ -6,6 +6,8 @@ from functools import reduce
 from Types import DataTypeByNum
 from Types import ParameterException, ConnectException
 from time import time
+from string import Template
+from pymilvus import __version__
 
 
 def getPackageVersion():
@@ -35,16 +37,19 @@ class PyOrm(object):
     port = 19530
     alias = "default"
 
-    def connect(self, alias=None, host=None, port=None, disconnect=False):
+    def connect(self, alias=None, host=None, port=None, disconnect=False, secure=False, username=None, password=None):
         self.alias = alias
         self.host = host
         self.port = port
+        trimUsername = None if username is None else username.strip()
+        trimPwd = None if password is None else password.strip()
+
         from pymilvus import connections
 
         if disconnect:
             connections.disconnect(alias)
             return
-        connections.connect(self.alias, host=self.host, port=self.port)
+        connections.connect(self.alias, host=self.host, port=self.port,user=trimUsername,password=trimPwd,secure=secure)
 
     def checkConnection(self):
         from pymilvus import list_collections
@@ -65,10 +70,10 @@ class PyOrm(object):
             )
         aliasList = map(lambda x: x[0], allConnections)
         if tempAlias in aliasList:
-            host, port = connections.get_connection_addr(tempAlias).values()
+            secure, host, port = connections.get_connection_addr(tempAlias).values()
             # return """Host: {}\nPort: {}\nAlias: {}""".format(host, port, alias)
             return tabulate(
-                [["Host", host], ["Port", port], ["Alias", tempAlias]],
+                [["Host", host], ["Port", port], ["Alias", tempAlias],["Secure",secure]],
                 tablefmt="pretty",
             )
         else:
@@ -89,7 +94,8 @@ class PyOrm(object):
         result = target.schema.fields
         if showVectorOnly:
             return reduce(
-                lambda x, y: x + [y.name] if y.dtype in [100, 101] else x, result, []
+                lambda x, y: x + [y.name] if y.dtype in [100,
+                                                         101] else x, result, []
             )
         return [i.name for i in result]
 
@@ -115,7 +121,7 @@ class PyOrm(object):
         collectionNames = self._list_collection_names(timeout)
         for name in collectionNames:
             loadingProgress = self.showCollectionLoadingProgress(name)
-            loaded, total = loadingProgress.values()
+            loaded, total, alias = loadingProgress.values()
             # isLoaded = (total > 0) and (loaded == total)
             # shouldBeAdded = isLoaded if showLoadedOnly else True
             # if shouldBeAdded:
@@ -194,9 +200,11 @@ class PyOrm(object):
         )
 
     def releasePartition(self, collectionName, partitionName):
-        targetPartition = self.getTargetPartition(collectionName, partitionName)
+        targetPartition = self.getTargetPartition(
+            collectionName, partitionName)
         targetPartition.release()
-        result = self.showCollectionLoadingProgress(collectionName, [partitionName])
+        result = self.showCollectionLoadingProgress(
+            collectionName, [partitionName])
         return result
 
     def releasePartitions(self, collectionName, partitionNameList):
@@ -204,16 +212,19 @@ class PyOrm(object):
         for name in partitionNameList:
             tmp = self.releasePartition(collectionName, name)
             result.append(
-                [name, tmp.get("num_loaded_entities"), tmp.get("num_total_entities")]
+                [name, tmp.get("num_loaded_entities"),
+                 tmp.get("num_total_entities")]
             )
         return tabulate(
             result, headers=["Partition Name", "Loaded", "Total"], tablefmt="grid"
         )
 
     def loadPartition(self, collectionName, partitionName):
-        targetPartition = self.getTargetPartition(collectionName, partitionName)
+        targetPartition = self.getTargetPartition(
+            collectionName, partitionName)
         targetPartition.load()
-        result = self.showCollectionLoadingProgress(collectionName, [partitionName])
+        result = self.showCollectionLoadingProgress(
+            collectionName, [partitionName])
         return result
 
     def loadPartitions(self, collectionName, partitionNameList):
@@ -221,7 +232,8 @@ class PyOrm(object):
         for name in partitionNameList:
             tmp = self.loadPartition(collectionName, name)
             result.append(
-                [name, tmp.get("num_loaded_entities"), tmp.get("num_total_entities")]
+                [name, tmp.get("num_loaded_entities"),
+                 tmp.get("num_total_entities")]
             )
         return tabulate(
             result, headers=["Partition Name", "Loaded", "Total"], tablefmt="grid"
@@ -280,8 +292,10 @@ class PyOrm(object):
         schemaDetails = """Description: {}\n\nAuto ID: {}\n\nFields(* is the primary field):{}""".format(
             schema.description, schema.auto_id, fieldSchemaDetails
         )
-        partitionDetails = "  - " + "\n- ".join(map(lambda x: x.name, partitions))
-        indexesDetails = "  - " + "\n- ".join(map(lambda x: x.field_name, indexes))
+        partitionDetails = "  - " + \
+            "\n- ".join(map(lambda x: x.name, partitions))
+        indexesDetails = "  - " + \
+            "\n- ".join(map(lambda x: x.field_name, indexes))
         rows.append(["Name", target.name])
         rows.append(["Description", target.description])
         rows.append(["Is Empty", target.is_empty])
@@ -313,7 +327,8 @@ class PyOrm(object):
         rows.append(["Index Type", index.params["index_type"]])
         rows.append(["Metric Type", index.params["metric_type"]])
         params = index.params["params"]
-        paramsDetails = "\n- ".join(map(lambda k: f"{k[0]}: {k[1]}", params.items()))
+        paramsDetails = "\n- ".join(
+            map(lambda k: f"{k[0]}: {k[1]}", params.items()))
         rows.append(["Params", paramsDetails])
         return tabulate(rows, tablefmt="grid")
 
@@ -329,7 +344,8 @@ class PyOrm(object):
             if fieldType in ["BINARY_VECTOR", "FLOAT_VECTOR"]:
                 fieldList.append(
                     FieldSchema(
-                        name=fieldName, dtype=DataType[fieldType], dim=int(fieldData)
+                        name=fieldName, dtype=DataType[fieldType], dim=int(
+                            fieldData)
                     )
                 )
             else:
@@ -417,7 +433,6 @@ class PyOrm(object):
 
     def query(self, collectionName, queryParameters):
         collection = self.getTargetCollection(collectionName)
-        collection.load()
         print(queryParameters)
         res = collection.query(**queryParameters)
         # return f"- Query results: {res}"
@@ -433,7 +448,8 @@ class PyOrm(object):
 
     def insert(self, collectionName, data, partitionName=None, timeout=None):
         collection = self.getTargetCollection(collectionName)
-        result = collection.insert(data, partition_name=partitionName, timeout=timeout)
+        result = collection.insert(
+            data, partition_name=partitionName, timeout=timeout)
         entitiesNum = collection.num_entities
         return [result, entitiesNum]
 
@@ -459,7 +475,8 @@ class PyOrm(object):
 
     def deleteEntities(self, expr, collectionName, partition_name=None, timeout=None):
         collection = self.getTargetCollection(collectionName)
-        result = collection.delete(expr, partition_name=partition_name, timeout=timeout)
+        result = collection.delete(
+            expr, partition_name=partition_name, timeout=timeout)
         return result
 
     def getQuerySegmentInfo(self, collectionName, timeout=None, prettierFormat=False):
@@ -471,7 +488,8 @@ class PyOrm(object):
         if not prettierFormat or not result:
             return result
         firstChild = result[0]
-        headers = ["segmentID", "collectionID", "partitionID", "mem_size", "num_rows"]
+        headers = ["segmentID", "collectionID",
+                   "partitionID", "mem_size", "num_rows"]
         return tabulate(
             [[getattr(_, i) for i in headers] for _ in result],
             headers=headers,
@@ -567,6 +585,33 @@ class PyOrm(object):
     # pymilvus.utility.mkts_from_datetime(d_time, milliseconds=0.0, delta=None)
     # pymilvus.utility.hybridts_to_datetime(hybridts, tz=None)
 
+    def compactCollection(self, collectionName, timeout=None):
+        collection = self.getTargetCollection(collectionName)
+        collection.compact(timeout=timeout)
+
+    def getCompactCollectionState(self, collectionName, timeout=None):
+        collection = self.getTargetCollection(collectionName)
+        return collection.get_compaction_state(timeout=timeout)
+
+    def getCompactCollectionPlans(self, collectionName, timeout=None):
+        collection = self.getTargetCollection(collectionName)
+        return collection.get_compaction_plans(timeout=timeout)
+
+    def listCredUsers(self):
+        from pymilvus import list_cred_users
+        users = list_cred_users(self.alias)
+        return users
+
+    def createCredUser(self, username=None, password=None):
+        from pymilvus import create_credential
+        create_credential(username, password, self.alias)
+        return self.listCredUsers()
+
+    def deleteCredUser(self, username=None):
+        from pymilvus import delete_credential
+        delete_credential(username, self.alias)
+        return self.listCredUsers()
+
 
 class Completer(object):
     # COMMANDS = ['clear', 'connect', 'create', 'delete', 'describe', 'exit',
@@ -580,20 +625,28 @@ class Completer(object):
             "hybridts_to_unixtime",
         ],
         "clear": [],
+        "compact": [],
         "connect": [],
-        "create": ["alias", "collection", "partition", "index"],
-        "delete": ["alias", "collection", "entities", "partition", "index"],
+        "create": ["alias", "collection", "partition", "index","user"],
+        "delete": ["alias", "collection", "entities", "partition", "index","user"],
         "describe": ["collection", "partition", "index"],
         "exit": [],
         "help": [],
         "import": [],
-        "list": ["collections", "partitions", "indexes"],
+        "list": ["collections", "partitions", "indexes","users"],
         "load_balance": [],
         "load": [],
         "query": [],
         "release": [],
         "search": [],
-        "show": ["connection", "index_progress", "loading_progress", "query_segment"],
+        "show": [
+            "connection",
+            "index_progress",
+            "loading_progress",
+            "query_segment",
+            "compaction_state",
+            "compaction_plans",
+        ],
         "version": [],
     }
 
@@ -682,11 +735,12 @@ class Completer(object):
             if args:
                 return (impl(args) + [None])[state]
             return [cmd + " "][state]
-        results = [c + " " for c in self.COMMANDS if c.startswith(cmd)] + [None]
+        results = [
+            c + " " for c in self.COMMANDS if c.startswith(cmd)] + [None]
         return results[state]
 
 
-WELCOME_MSG = """
+msgTemp = Template("""
                                                
                                                
   __  __ _ _                    ____ _     ___ 
@@ -695,9 +749,14 @@ WELCOME_MSG = """
  | |  | | | |\ V /| |_| \__ \ | |___| |___ | | 
  |_|  |_|_|_| \_/  \__,_|___/  \____|_____|___|
                                                
-                                               
+Milvus cli version: ${cli}
+Pymilvus version: ${py}                                             
+
 Learn more: https://github.com/zilliztech/milvus_cli.
 
-"""
+""")
+
+
+WELCOME_MSG = msgTemp.safe_substitute(cli=getPackageVersion(), py=__version__)
 
 EXIT_MSG = "\n\nThanks for using.\nWe hope your feedback: https://github.com/zilliztech/milvus_cli/issues/new.\n\n"
